pub struct FilteredFetcher<F, A> { /* private fields */ }Expand description
A fetcher decorator that applies a filter to results.
This wraps any AddressFetcher and filters the returned adapters
using the provided AdapterFilter.
Type Parameters
F: The inner fetcher type (implementsAddressFetcher)A: The filter type (implementsAdapterFilter)
Examples
ⓘ
use ddns_a::network::filter::{FilteredFetcher, FilterChain, KindFilter};
use ddns_a::network::{AdapterKind, platform::WindowsFetcher};
let filter = FilterChain::new()
.exclude(KindFilter::new([AdapterKind::Virtual, AdapterKind::Loopback]));
let fetcher = FilteredFetcher::new(WindowsFetcher::new(), filter);
let adapters = fetcher.fetch()?; // Only non-virtual, non-loopback adaptersImplementations
Sourceimpl<F, A> FilteredFetcher<F, A>
impl<F, A> FilteredFetcher<F, A>
Sourcepub fn into_inner(self) -> F
pub fn into_inner(self) -> F
Consumes the filtered fetcher and returns the inner fetcher.